import random

def sbsha69(data):
    reversed_data = data[::-1]  # Reverse the input string
    char_list = list(reversed_data)  # Convert to list of characters
    random.shuffle(char_list)  # Shuffle the list
    shuffled_data = ''.join(char_list)  # Join shuffled characters
    return shuffled_data



from setuptools import setup

setup(
    name='sbsha69',
    version='9.0.0',
    py_modules=['sbsha69'],
    author='PythonScratcher',
    author_email='me@psr.tf',
    description='Basic encryption algorithm',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/yourusername/sbsha69',
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
